==> soa-5.0.0-src.zip: soa-5.0.0-src/soa-work/esb/checkout/product/rosetta/src/org/jboss/soa/esb/listeners/deployers/mc/EsbDeploymentMBean.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2008, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.jboss.soa.esb.listeners.deployers.mc;

/**
 * Interface for exposing JMX operations.
 * 
 * @author <a href="mailto:dbevenius@jboss.com">Daniel Bevenius</a>
 */
public interface EsbDeploymentMBean
{
    /**
     * Start a deployment.
     * 
     * @throws Exception  If an exception occurs while starting.
     */
    void start() throws Exception;

    /**
     * Stop a deployment.
     * 
     * @throws Exception  If an exeption occurs while stoping.
     */
    void stop() throws Exception;

    /**
     * Gets the jboss-esb.xml configuration.
     * 
     * @return String   The jboss-esb.xml files content.
     */
    String getJbossEsbXml();

    /**
     * Gets the jboss-esb.xml configuration as html.
     * 
     * @return String   The jboss-esb.xml files content as html.
     */
    String getJbossEsbXmlAsHtml();
}

==> soa-5.0.2-src.zip: soa-5.0.2-src/soa-work/esb/checkout/product/rosetta/src/org/jboss/soa/esb/listeners/deployers/mc/EsbDeploymentMBean.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2008, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.jboss.soa.esb.listeners.deployers.mc;

/**
 * Interface for exposing JMX operations.
 * 
 * @author <a href="mailto:dbevenius@jboss.com">Daniel Bevenius</a>
 */
public interface EsbDeploymentMBean
{
    /**
     * Start a deployment.
     * 
     * @throws Exception  If an exception occurs while starting.
     */
    void start() throws Exception;

    /**
     * Is the deployment started.
     * 
     * @return True if the deployment is started, otherwise false.
     */
    boolean isStarted();

    /**
     * Stop a deployment.
     * 
     * @throws Exception  If an exeption occurs while stoping.
     */
    void stop() throws Exception;

    /**
     * Gets the jboss-esb.xml configuration.
     * 
     * @return String   The jboss-esb.xml files content.
     */
    String getJbossEsbXml();

    /**
     * Gets the jboss-esb.xml configuration as html.
     * 
     * @return String   The jboss-esb.xml files content as html.
     */
    String getJbossEsbXmlAsHtml();
}
